

# Now I Can Sleep

A minimalist automated documentation generation tool for a GitHub repository.

![nics' banner](https://raw.githubusercontent.com/nvfp/now-i-can-sleep/master/assets/20230627-nics-logo.png)


## Installation

1. Install via pip `pip install nics`
2. Navigate to your project root directory
3. Run `nics init`
4. Follow the wizard, and you all set!


## Links

- [Documentation](https://nvfp.github.io/now-i-can-sleep)
- [Changelog](https://nvfp.github.io/now-i-can-sleep/changelog)
- [💙Supporters](https://nvfp.github.io/now-i-can-sleep/supporters)


## Troubleshoot

- To report bugs or ask questions, you can open an issue or submit a pull request.


## License

This project is licensed under the MIT license.